Functions
- collect_
and_ align_ results - Collect and align results with original records
- compute_
mean - Calculate the mean of for a slice of f32 values There’s no need for a generic implementation here, as we only need f32 for embeddings
- compute_
similarity - generate_
embeddings_ for_ record - Helper for extracting embeddings for a single record. Used in the genai evaulation workflow.
- parse_
embedder - Helper function for extracting embedder and runtime from optional PyEmbedder
- post_
process_ aligned_ results - Post-process aligned results
- spawn_
evaluation_ tasks_ with_ embeddings - Spawn tasks to run evaluation workflows with embedding calculations
- spawn_
evaluation_ tasks_ without_ embeddings - Spawn tasks without embedding support This function will spawn a task that runs the workflows and extracts the results If there is an error during workflow execution, it will log the error and return None for that record