spawn_evaluation_tasks_without_embeddings

Function spawn_evaluation_tasks_without_embeddings 

pub async fn spawn_evaluation_tasks_without_embeddings(
    dataset: &GenAIEvalDataset,
    _config: &Arc<EvaluationConfig>,
) -> JoinSet<(usize, Result<(GenAIEvalSet, BTreeMap<String, Vec<f32>>), String>)>
Spawn tasks without embedding support This function will spawn a task that runs the workflows and extracts the results If there is an error during workflow execution, it will log the error and return None for that record

Arguments

  • workflow - The workflow to execute for each record.
  • records - The list of GenAIEvalRecords to process.

Returns

A JoinSet containing tuples of record ID and optional GenAIEvalTaskResult.